@@ -2,13 +2,16 @@
 set -euxo pipefail
 # Used by Zuul CI to perform extra bootstrapping
 
+sudo dd if=/dev/zero of=/swap.img bs=1024 count=1048576
+sudo chmod 600 /swap.img
+sudo mkswap /swap.img
+sudo swapon /swap.img
+
 # Platforms coverage:
 # Fedora 30 : has vagrant-libvirt no compilation needed
 # CentOS 7  : install upstream vagrant rpm and compiles plugin (broken runtime)
 # CentOS 8  : install upstream vagrant rpm and compiles plugin (broken runtime)
 
-DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
-
 # Bumping system tox because version from CentOS 7 is too old
 # We are not using pip --user due to few bugs in tox role which does not allow
 # us to override how is called. Once these are addressed we will switch back
@@ -136,13 +139,4 @@ vagrant plugin list | tee >(grep -q "No plugins installed." && {
     exit 1
 })
 
-# Used to test that Vagrant is usable and also to pre-download the image
-# we will use during testing.
-cd $DIR
-
-# sudo su: dirty hack to make sure that usermod change has been taken into account
-timeout 300 vagrant up --no-tty --debug
-timeout 300 vagrant halt
-timeout 300 vagrant package --output testbox.box
-vagrant box add testbox.box --name testbox
-vagrant destroy -f
+timeout 600 ./tools/create_testbox.sh
